yakumo.cinder.v2.volume_backup

Package yakumo :: Package cinder :: Package v2 :: Module volume_backup |
[hide private]
[frames] | no frames]

# Module volume_backup

source code

Resource class and its manager for volume backup on Block Storage V2 API

Classes | [hide private]
| Resource resource class for volume backups on Block Storage V2 API
| Manager manager class for volume backups on Block Storage V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.cinder.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'display_name', mapper.Noop), ('d
      escription', 'description', mapper.Noop), ('availability_zone', 'avail
      ability_zone', mapper.Resource('availability_zone')), ('source_volume'
      , 'volume_id', mapper.Resource('cinder.volume')), ('size', 'size', map
      per.Noop), ('object_count', 'object_count', mapper.Noop), ('container'
      , 'container', mapper.Noop), ('created_at', 'created_at', mapper.DateT
      ime), ('updated_at', 'updated_at', mapper.DateTime), ('status', 'statu
      s', mapper.Noop), ('fail_reason', 'fail_reason', mapper.Noop), ('has_d
      ...